tRNAnalysis
===========


This workflow was generated as a response to not being able to effectively analyse tRNA data from next generation sequencing experiments. Typical workflows are not very flexible and do not scale well for multiple samples. Moreover, most do not impliment best-practice mapping strategies or generate detailed analysis reports to aid biological interpretation.

The pipeline can be used for evaluating the levels of small RNAs in a sample but provides detailed analysis of tRNAs, with particular emphasis on tRNA fragment analysis.

Installation
------------

Documentation
-------------

Further help that introduces tRNAnalysis and provides a tutorial of how to run example
code can be found at `read the docs <https://trnanalysis.readthedocs.io/en/latest/>`_
